@@ -6,6 +6,7 @@ Each action has an id, name, timestamp and it's set of edges.
 from .item import item
 from jaseci.actions.live_actions import live_actions
 import inspect
+
 # ACTION_PACKAGE = 'jaseci.actions.'
 
 
@@ -20,8 +21,7 @@ class action(item):
     access_list is used by walker to decide what to trigger
     """
 
-    def __init__(self, preset_in_out=None, access_list=None,
-                 *args, **kwargs):
+    def __init__(self, preset_in_out=None, access_list=None, *args, **kwargs):
         self.preset_in_out = preset_in_out  # Not using _ids convention
         self.access_list = access_list
         super().__init__(*args, **kwargs)
@@ -34,12 +34,17 @@ class action(item):
         """
         func = live_actions[self.value]
         args = inspect.getfullargspec(func)
-        args = args[0]+args[4]
-        if('meta' in args):
-            result = func(*param_list,
-                          meta={'m_id': scope.parent._m_id,
-                                'h': scope.parent._h, 'scope': scope,
-                                'interp':  interp})
+        args = args[0] + args[4]
+        if "meta" in args:
+            result = func(
+                *param_list,
+                meta={
+                    "m_id": scope.parent._m_id,
+                    "h": scope.parent._h,
+                    "scope": scope,
+                    "interp": interp,
+                }
+            )
         else:
             result = func(*param_list)
         return result
