@@ -124,6 +124,12 @@ class machine_state:
             self.rt_error(f"Builtin action not found - {func_name}", jac_ast)
         return func_name
 
+    def jac_try_exception(self, e: Exception, jac_ast):
+        if isinstance(e, TryException):
+            raise e
+        else:
+            raise TryException(self.jac_exception(e, jac_ast))
+
     def jac_exception(self, e: Exception, jac_ast):
         return {
             "type": type(e).__name__,
@@ -132,6 +138,8 @@ class machine_state:
             "args": e.args,
             "line": jac_ast.line,
             "col": jac_ast.column,
+            "name": self.name if hasattr(self, "name") else "blank",
+            "rule": jac_ast.name,
         }
 
     def rt_log_str(self, msg, jac_ast=None):
@@ -187,3 +195,9 @@ class machine_state:
             "request_context": self.request_context,
             "runtime_errors": self.runtime_errors,
         }
+
+
+class TryException(Exception):
+    def __init__(self, ref: dict):
+        super().__init__(ref["msg"])
+        self.ref = ref
